@@ -13,14 +13,14 @@ class MpvObject : public MpvAbstractItem
     Q_OBJECT
     QML_ELEMENT
 
-    Q_PROPERTY(qreal position READ position NOTIFY positionChanged)
+    Q_PROPERTY(qreal position READ position WRITE setPosition NOTIFY positionChanged)
     Q_PROPERTY(qreal duration READ duration NOTIFY durationChanged)
     Q_PROPERTY(bool paused READ paused NOTIFY pausedChanged)
     Q_PROPERTY(bool stopped READ stopped NOTIFY stoppedChanged)
 
 public:
     explicit MpvObject(QQuickItem *parent = nullptr);
-    ~MpvObject() = default;
+    ~MpvObject() override = default;
 
     void setAudioUrl(const QString &audioUrl);
 
